@@ -8,7 +8,7 @@ use Log::ger;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-12-01'; # DATE
 our $DIST = 'Complete-Color'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Complete::Common qw(:all);
 use Exporter qw(import);
@@ -62,7 +62,9 @@ sub complete_color_name {
 
     require Complete::Util;
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
-    Complete::Util::complete_hash_key(hash => ${"$mod\::NAMES_RGB_TABLE"}, word=>$args{word}, summaries_from_hash_values=>1);
+    my %summaries;
+    for (keys %{${"$mod\::NAMES_RGB_TABLE"}}) { $summaries{$_} = "code #".${"$mod\::NAMES_RGB_TABLE"}->{$_}.", ".${"$mod\::NAMES_SUMMARIES_TABLE"}->{$_} }
+    Complete::Util::complete_hash_key(hash => ${"$mod\::NAMES_RGB_TABLE"}, word=>$args{word}, summaries=>\%summaries);
 }
 
 $SPEC{'complete_color_rgb24_hexcode'} = {
@@ -131,7 +133,7 @@ Complete::Color - Completion routines related to colors
 
 =head1 VERSION
 
-This document describes version 0.002 of Complete::Color (from Perl distribution Complete-Color), released on 2023-12-01.
+This document describes version 0.003 of Complete::Color (from Perl distribution Complete-Color), released on 2023-12-01.
 
 =for Pod::Coverage .+
 
